/*
 * Created on Aug 22, 2005
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 675 Mass
 * Ave, Cambridge, MA 02139, USA.
 * 
 * History
 * v1.0 - Aug 22, 2005 - Initial Release
 */

/**
 * @author kuwanger
 *
 * A very simple (read, incomplete) Little Endian compatible "OutputStream"
 */

import java.io.DataOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.FileNotFoundException;

public class LESimpleDataOutputStream {
	private DataOutputStream out;
	
	LESimpleDataOutputStream(String filename) throws FileNotFoundException
	{
		out = new DataOutputStream(new FileOutputStream(filename));
	}
	
	void close() throws IOException
	{
		out.close();
	}
	
	void writeByte(byte b) throws IOException
	{
		out.writeByte(b);
	}

	void writeBytes(byte[] bytes) throws IOException
	{
		for (int i = 0; i < bytes.length; i++)
			writeByte(bytes[i]);
	}

	void writeBytes(char[] chars) throws IOException
	{
		byte b;
		for (int i = 0; i < chars.length; i++)
		{
			//b = (byte) ((((chars[i]&128) == 128) ? -128 : 0) + (byte) chars[i]);
			b = (byte) chars[i];
			writeByte(b);
		}
	}
	
	void writeChar(char c) throws IOException
	{
		c = (char) (c<<8 | c>>8);
		out.writeChar(c);
	}
	
	void writeChars(char[] chars) throws IOException
	{
		for (int i = 0; i < chars.length; i++)
			writeChar(chars[i]);
	}
	
	void writeInt(int i) throws IOException
	{
		i = i<<24 | ((i << 8) & 0x00FF0000) | ((i >> 8) & 0x0000FF00) | i >>>24;
		out.writeInt(i);
	}
	
	void writeInts(int[] ints) throws IOException
	{
		for (int i = 0; i < ints.length; i++)
			writeInt(ints[i]);
	}
	
	void writeString(String s) throws IOException
	{
		out.writeBytes(s);
	}

	void writeString(String s, int len) throws IOException
	{
		int i;
		byte[] b = s.getBytes("US-ASCII");
		
		for (i = 0; i < len - 1 && i < b.length; i++)
			out.writeByte(b[i]);
	
		for (; i < len; i++)
			out.writeByte(0);
	}
}
